from distutils.core import setup
setup(
    name='zhangda',
    version='1.0',
    description='这是一个测试',
    author='zhanghui',
    author_email='739628252@qq.com',
    py_modules=['jiangda.demo','jiangda.demo2']

)